import React, {Component, Fragment} from 'react';
import './overall.scss';
import {JFLoading} from "../../component/JFLoading/JFLoading";
import {observer,inject} from "mobx-react/index";
import {JFPageHeader} from "../../component/JFPageHeader/JFPageHeader";
import {JFContent, JFContentHeader} from "../../component/JFContent/JFContent";
import {Icon, Switch} from 'antd';
import Clipboard from 'react-clipboard.js';
import {CartesianGrid, Line, LineChart, ResponsiveContainer, Tooltip, XAxis, YAxis} from "recharts";
import {Message} from "../../common/message";
import {numberSplit} from "../../common/utils";

import CKEditor from '@ckeditor/ckeditor5-react';
import ClassicEditor from '@ckeditor/ckeditor5-editor-classic/src/classiceditor';
import Alignment from '@ckeditor/ckeditor5-alignment/src/alignment';
import Heading from '@ckeditor/ckeditor5-heading/src/heading';
// import Bold from '@ckeditor/ckeditor5-basic-styles/src/bold';
// import Italic from '@ckeditor/ckeditor5-basic-styles/src/italic';
// import Paragraph from '@ckeditor/ckeditor5-paragraph/src/paragraph';



const ckEditorConfig = {
    plugins:[ Heading, ],
    toolbar: [
            'heading',
            '|',
            // 'alignment',                                                 // <--- ADDED
            // 'bold',
            // 'italic',
            // 'link',
            // 'bulletedList',
            // 'numberedList',
            // 'imageUpload',
            // 'blockQuote',
            // 'undo',
            // 'redo'
        ]
};

@inject('overallStore', 'appStore')
@observer
class Overall extends Component {

    componentDidMount() {
        this.props.overallStore.init();
    }

    render() {
        let obj = {};
        let { overallStore, appStore } = this.props;
        let pvData = overallStore.pvInfo
            .filter(({ day,flows }) => { return flows.length !== 0  })
            .map(({ day,flows }) => { return { day,...(function () {
                obj = {};
                for (let i =0; i<flows.length; i++) {
                    obj['f'+i] = flows[i].count
                }
                return obj;
            }())}});
        return (
            <Fragment>
                <JFLoading loading={overallStore.loading} mask={true} />
                <div className={'ps-overall'}>
                    <JFPageHeader routes={[{ name:'总览' }]}/>
                    <JFContent>
                        <CKEditor
                            editor={ ClassicEditor }
                            data="<p>Hello from CKEditor 5!</p>"
                            config={ ckEditorConfig }
                            onInit={ editor => {
                                // You can store the "editor" and use when it is needed.
                                console.log( 'Editor is ready to use!', editor );
                            } }
                            onChange={ ( event, editor ) => {
                                const data = editor.getData();
                                console.log( { event, editor, data } );
                            } }
                            onBlur={ editor => {
                                console.log( 'Blur.', editor );
                            } }
                            onFocus={ editor => {
                                console.log( 'Focus.', editor );
                            } }
                        />
                    </JFContent>
                </div>
            </Fragment>
        );
    }
}

export default Overall;
